.. oapackage documentation master file, created by
   sphinx-quickstart on Tue Jun 26 20:08:57 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to oapackage's documentation!
=====================================

The Orthogonal Array package contains functionality to generate and analyse orthogonal arrays,
optimal designs and conference designs.


.. toctree::
   :maxdepth: 1
   :caption: Contents:

   oapackage-intro
   examplenotebooks
   data
   generation
   normalform
   properties
   cpplib
   references   

   
   
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

License
=======

.. include:: ../LICENSE


